@@ -38,9 +38,16 @@ def version_string(path=None, *, valid_semver=False):
     if tag.returncode == 0:
         version = tag.stdout.strip().decode("utf-8", "strict")
     else:
-        describe = subprocess.run("git describe --tags", shell=True, stdout=subprocess.PIPE, cwd=path)
-        tag, additional_commits, commitish = describe.stdout.strip().decode("utf-8", "strict").rsplit("-", maxsplit=2)
-        commitish = commitish[1:]
+        describe = subprocess.run("git describe --tags --always", shell=True, stdout=subprocess.PIPE, cwd=path)
+        describe = describe.stdout.strip().decode("utf-8", "strict").rsplit("-", maxsplit=2)
+        if len(describe) == 3:
+            tag, additional_commits, commitish = describe.stdout.strip().decode("utf-8", "strict").rsplit("-", maxsplit=2)
+            commitish = commitish[1:]
+        else:
+            tag = "0.0.0"
+            commit_count = subprocess.run("git rev-list --count HEAD", shell=True, stdout=subprocess.PIPE, cwd=path)
+            additional_commits = commit_count.stdout.strip().decode("utf-8", "strict")
+            commitish = describe[0]
         if valid_semver:
             version_info = semver.parse_version_info(tag)
             if not version_info.prerelease:
@@ -101,12 +108,8 @@ def library(library_path, output_directory, mpy_cross=None):
             py_files.append(filename)
 
     if len(py_files) > 1:
-        output_directory = os.path.join(output_directory, library)
-        os.makedirs(output_directory)
-        package_init = os.path.join(output_directory, "__init__.py")
-        # Touch the __init__ file.
-        with open(package_init, 'a'):
-            pass
+        raise ValueError("Multiple top level py files not allowed. Please put them in a package "
+                         "or combine them into a single file.")
 
     if len(package_files) > 1:
         for fn in package_files:
@@ -120,7 +123,12 @@ def library(library_path, output_directory, mpy_cross=None):
     if mpy_cross:
         new_extension = ".mpy"
 
-    library_version = version_string(library_path, valid_semver=True)
+    try:
+        library_version = version_string(library_path, valid_semver=True)
+    except ValueError as e:
+        print(library_path + " has version that doesn't follow SemVer (semver.org)")
+        print(e)
+        library_version = version_string(library_path)
 
     for filename in py_files:
         full_path = os.path.join(library_path, filename)
